@@ -8,13 +8,14 @@ use Types::Standard -all;
 use Types::TypeTiny -all;
 use GraphQL::Type::Library -all;
 use Function::Parameters;
-use GraphQL::Language::Parser;
+use GraphQL::Language::Parser qw(parse);
 use GraphQL::Error;
 use JSON::MaybeXS;
 use GraphQL::Debug qw(_debug);
 use GraphQL::Introspection qw(
   $SCHEMA_META_FIELD_DEF $TYPE_META_FIELD_DEF $TYPE_NAME_META_FIELD_DEF
 );
+use base qw(Exporter);
 
 =head1 NAME
 
@@ -22,6 +23,9 @@ GraphQL::Execution - Execute GraphQL queries
 
 =cut
 
+our @EXPORT_OK = qw(
+  execute
+);
 our $VERSION = '0.02';
 
 my $JSON = JSON::MaybeXS->new->allow_nonref;
@@ -29,8 +33,8 @@ use constant DEBUG => $ENV{GRAPHQL_DEBUG}; # "DEBUG and" gets optimised out if f
 
 =head1 SYNOPSIS
 
-  use GraphQL::Execution;
-  my $result = GraphQL::Execution->execute($schema, $doc, $root_value);
+  use GraphQL::Execution qw(execute);
+  my $result = execute($schema, $doc, $root_value);
 
 =head1 DESCRIPTION
 
@@ -40,7 +44,7 @@ Executes a GraphQL query, returns results.
 
 =head2 execute
 
-  my $result = GraphQL::Execution->execute(
+  my $result = execute(
     $schema,
     $doc,
     $root_value,
@@ -52,7 +56,7 @@ Executes a GraphQL query, returns results.
 
 =cut
 
-method execute(
+fun execute(
   (InstanceOf['GraphQL::Schema']) $schema,
   Str $doc,
   Any $root_value = undef,
@@ -62,7 +66,7 @@ method execute(
   Maybe[CodeLike] $field_resolver = undef,
 ) :ReturnType(HashRef) {
   my $context = eval {
-    my $ast = GraphQL::Language::Parser->parse($doc);
+    my $ast = parse($doc);
     _build_context(
       $schema,
       $ast,
@@ -627,7 +631,7 @@ fun _collect_and_execute_subfields(
       $visited_fragment_names,
     );
   }
-  DEBUG and _debug('_collect_and_execute_subfields', $return_type->to_string, $subfield_nodes);
+  DEBUG and _debug('_collect_and_execute_subfields', $return_type->to_string, $subfield_nodes, $result);
   _execute_fields($context, $return_type, $result, $path, $subfield_nodes);
 }
 
